@@ -77,6 +77,10 @@ class BundleUploader < AMITool
 
   #----------------------------------------------------------------------------#
 
+  # 
+  # Availability zone names are generally in the format => ${REGION}${ZONENUMBER}.
+  # Examples being us-east-1b, us-east-1c, etc.
+  #
   def get_availability_zone()
     instance_data = EC2::InstanceData.new
     instance_data.availability_zone
@@ -186,19 +190,25 @@ class BundleUploader < AMITool
 
   #------------------------------------------------------------------------------#
 
+  # mapping from region names to S3 location constraints
   S3_LOCATION_CONSTRAINTS = {
-    'us-east-1' => :unconstrained,
-    'eu-west-1' => 'EU',
-    'us-west-1' => 'us-west-1'
+    'us-east-1'      => :unconstrained,
+    'eu-west-1'      => 'EU',
+    'us-west-1'      => 'us-west-1',
+    'ap-southeast-1' => 'ap-southeast-1',
+    'ap-northeast-1' => 'ap-northeast-1',
   }
   
+  # list of regions
+  REGIONS = ['us-east-1', 'eu-west-1', 'us-west-1', 'ap-southeast-1', 'ap-northeast-1']
+
   def get_region()
     zone = get_availability_zone()
     if zone.nil?
       return nil
     end
     # assume region names do not have a common naming scheme. Therefore we manually go through all known region names
-    ['us-east-1', 'eu-west-1', 'us-west-1'].each do |region| 
+    REGIONS.each do |region| 
       match = zone.match(region)
       if not match.nil?
         return region
